/v1/projects/{project_id}/vpcs/vms/{vm_id}/start — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »

# /v1/projects/{project_id}/vpcs/vms/{vm_id}/start

Contents

- /v1/projects/{project_id}/vpcs/vms/{vm_id}/start
  - POST /v1/projects/{project_id}/vpcs/vms/{vm_id}/start
    - Parameters
    - Response status codes

## POST /v1/projects/{project_id}/vpcs/vms/{vm_id}/start

Start a VPCS instance

### Parameters

- project_id: UUID for the project
- vm_id: UUID for the instance

### Response status codes

- 400: Invalid request
- 404: Instance doesn’t exist
- 204: Instance started

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »